//*****"Sneakin Out" POV-Ray Scene by NEWT
//*****(C)2004 Indulgent Studios

//*****Feel free to use and modify.

#version 3.5;

#include "colors.inc"
#include "textures.inc"
#include "metals.inc"
#include "functions.inc"      
#include "glass.inc"   
    

global_settings { 
        assumed_gamma 1.8
        photons {
                spacing 0.01  
                autostop 0
                jitter 0.5
                max_trace_level 15
        }    
}                 

#declare dof=0; // focal blur 
#declare detail=1; // detailed buildings


//*****CAMERA*****
 
camera {  
        location  <25,100,-19>
        look_at   <0,75,0>
        right     image_width*x/image_height
        
        #if (dof=1)
                focal_point <0,75,0>
                aperture 0.35
                blur_samples 40
                variance 0
                confidence 0.99
        #end
}


//*****SKY*****

sky_sphere {
    pigment {
        gradient y
        color_map{
            [0 color rgb <0.8,0.8,0.8>]
            [1 color rgb <0.0,0.0,0.0>]
            
        }   
    } 

} 

sphere { 0,1 scale <1000000,100,1000000> translate 5000*y pigment { Black } finish { diffuse 0 }}  


//*****LIGHTS*****                          
   
light_source { <300,500,-300> color rgb 1.7*1.2 }
light_source { <80,100,-100>  color rgb <0.5,0.8,1.0> shadowless } // blue tint          


//*****BUILDINGS AND DECORATIVE PARTS***** 

// textures

#declare met_tex1 = material {
        texture {
                pigment { rgb <0.5,0.5,0.5> }
                normal { granite 0.1 }
                finish { Metal }
                scale 0.01
        }
}    


#declare met_tex2 = 
material {
        texture {
                pigment { rgb <0.3,0.3,0.3> }
                normal { granite 0.1 }
                finish { Metal }
                scale 0.01
        }
}    
   
   
#declare roof_tex = material {
        texture {
                pigment {
                        slope y // for nice color bleeding             
                                color_map{
                                        [0.55 color rgb <0.7,0.7,0.7>]
                                        [1 color rgb <0.8,1.0,0.0>]
                                }  
                        translate 0*y 
                }
                finish { Metal }
        }
}             


// decorative elements

#declare spear =
        union {
                cylinder { 0*y,2*y,0.05 }  
                cone { 1.8*y,0.0,2*y,0.1 }   
                cone { 2*y,0.1,2.5*y,0 }
                sphere { 1.5*y,0.11 }  
                sphere { <-0.05,0.3,-0.05>,0.07 }  
                sphere { <0.05,0.3,-0.05>,0.07 }
                sphere { <-0.05,0.3,0.05>,0.07 }
                sphere { <0.05,0.3,0.05>,0.07 }
        }
          
        
#declare fence1 =                    
        union {
                object { spear translate z*-0.2 }  
                object { spear translate z*-0.8 }
                difference { 
                        torus { 0.3,0.05 rotate z*90 }
                        box { <-1,1,-1>,<1,0,1> }
                        translate <0,1.4,-0.5>
                }
                cylinder { 0*y,1.1*y,0.03 translate z*-0.5 }
        } 
         
        
#declare fence2 = 
        union {
                object { spear translate z*-0.4 }  
                object { spear translate z*-0.8 }
                difference { 
                        torus { 0.2,0.05 rotate z*90 }
                        box { <-1,1,-1>,<1,0,1> }
                        translate <0,1.4,-0.6>
                }
                cylinder { 0*y,1.1*y,0.03 translate z*-0.6 }
        }  
              
                                        
#declare nut = difference {
        union {
                cylinder { 0*x,1*x,0.5 }
                sphere { 0,0.5 scale <0.2,1,1> translate 1*x }
        }
        box { <-1,-0.2,-0.2>,<2,0.2,0.2> }                    
}    
             
             
#declare nut1 = union {
        cylinder { 0*x,2*x,0.5 }
        sphere { 0,0.5 scale <0.2,1,1> translate 2*x }
}


#declare link1 = difference { 
        cylinder { 27*y,30*y,2 }
        torus { 2,0.5 scale <1,3,1> translate 28.5*y }
} 


#declare link2 = union {
        sphere { 0,2.1 scale <1,5,1> translate <18,-1,0> }
        sphere_sweep {          
                        b_spline
                        11,
                        <0, 0, 0>, 6
                        <-5, 0, 0>, 6  
                        <-5, 15, 0>, 5   
                        <0, 30, 0>, 4             
                        <50, 40, 0>, 4 
                        <65, 70, 0>, 4                
                        <30, 100, 0>, 3
                        < 40, 115, 0>, 2      
                        < 50, 115, 0>, 2
                        < 55, 100, 0>, 2  
                        < 40, 100, 0>, 3 
                        tolerance 0.001
                        rotate 180*z 
                        scale 0.28    
                        translate <17,0,0>
                }      
        scale 2  
} 
  
  
// building elements

#declare col2 = union {
        #declare i=0; 
        #while (i<=9)
                cylinder { 2*y,28*y,1 scale <1,1,0.6> translate 1*x rotate 36*i*y }
                #declare i=i+1;
        #end 
        difference { cylinder { 0*y,3*y,3 }
                torus { 3,1 scale <1,1.5,1> translate 3*y }
        } 
        torus { 3,0.2 translate 0*y } 
        torus { 2,0.2 translate 3*y }         
        difference { cylinder { 27*y,30*y,3 }
                torus { 3,1 scale <1,1.5,1> translate 27*y }
        } 
        torus { 3,0.2 translate 30*y }   
        torus { 2,0.2 translate 27*y }         
}  


#declare arc1 = sphere_sweep {                
        b_spline
        7,
        <-5, 0, 0>, 1  
        <-5, 0, 0>, 1             
        <-5, 10, 0>, 1 
        <-5, 20, 0>, 1                
        < -3.3, 35, 0>, 1
        < 0, 40, 0>, 1.2      
        < 0, 40, 0>, 2 
        tolerance 0.001             
} 

 
#declare arc3 = union { 
        union {
                object { arc1 rotate 0*y } 
                object { arc1 rotate 180*y }
                prism { linear_sweep  
                        linear_spline 
                        -2.0,         
                        2.0,        
                        4,           
                        <-0.0,36.0>,<-2.0,40.5>,<2.0,40.5>,<0.0,36.0>
                        rotate -90*x
                }      
                scale <1.2,0.74,1>
        }
        object { col2 scale <0.65,1,0.65> translate -6*x }                            
}


#declare tower1 = union {
        lathe {
                linear_spline 9, 
                <0, 0>, <6.5, 0>, <7.5, 1>, <7.5, 3>, <7, 3.5>, <7, 7>, <8, 8>, <8, 12>, <0, 41>
        }
        sphere { <0,44,0>,1.5  }
        sphere { 0,0.5 scale <1,25,1> translate 41*y  } 
}


#declare tower2 = union {
        lathe {
                cubic_spline 9, 
                <0, 0>, <7.5, 0>, <8, 1>, <8, 3>, <6, 8>, <1.5, 15>, <0.5, 20>, <0.2, 22>, <0, 22>
        }  
        sphere { <0,20,0>,1  }
        sphere { 0,0.3 scale <1,25,1> translate 20*y  }
        material { roof_tex }  
}               


#declare tower3 = union {
        #declare i=0;
        #declare c=6;
        #while (i<=c)
                object { arc3 translate <0,0,-12.5> rotate -360/(c+1)*i*y }
        #declare i=i+1;
        #end           
        object { tower2 scale 2 translate 30*y }                         
}      
 
 
#macro tower4(height) 
        union { object { link2 }
                #declare j=0;
                #declare i=0;
                #while (j<height)  
                        #while (i<=6)
                                object { nut scale 3 translate 5*x rotate 360/7*i*y translate <36,5+j,0> }
                                #declare i=i+1;
                        #end 
                        #declare i=0;
                        #declare j=j+10;
                #end               
                cylinder { <36,-10,0>,<36,height,0>,6 }
                object { tower1 translate <36,height,0> }
        } 
        scale 0.55
#end       


#declare tower5 = union {
        #declare i=0;
        #declare c=6;
        #while (i<=c)
                object { arc3 translate <0,0,-12.5> rotate -360/(c+1)*i*y }
        #declare i=i+1;
        #end           
        torus { 13,2 scale <1,0.5,1> translate 30*y }                           
}


#declare net =
pigment { brick color 1 color rgb 0 mortar 2 rotate 90*x scale .01 }
     
     
#declare wall =
        height_field {
                function 1000,1000 {
                        pigment { net }
                }
        water_level 0.1     
}        


#declare floorr = union {
        object { wall scale <26,0.4,26> translate <-13,-0.2,-13> }
        cylinder { <-13,0,-13>,<13,0,-13>,0.4 }   
        cylinder { <-13,0,13>,<-13,0,-13>,0.4 } 
        cylinder { <13,0,-13>,<13,0,13>,0.4 } 
        cylinder { <13,0,13>,<-13,0,13>,0.4 }  
        sphere { <-13,0,-13>,0.4 } 
        sphere { <-13,0,13>,0.4 } 
        sphere { <13,0,-13>,0.4 } 
        sphere { <13,0,13>,0.4 } 
}         


// main building element
#declare s=seed(123);           
#macro cube1(n)
union {
        object { col2 scale 0.9 translate <-10,0,-10> } 
        object { col2 scale 0.9 translate <10,0,-10> } 
        object { col2 scale 0.9 translate <-10,0,10> } 
        object { col2 scale 0.9 translate <10,0,10> }       
        object  { wall scale <20,0.4,30*0.9> rotate x*-90 translate <-10,0,-10> }  
        object  { wall scale <20,0.4,30*0.9> rotate x*-90 translate <-10,0,10> }
        object  { wall scale <20,0.4,30*0.9> rotate <-90,-90,0> translate <-10,0,-10> } 
        object  { wall scale <20,0.4,30*0.9> rotate <-90,-90,0> translate <10,0,-10> } 
        cylinder { <-10,28.5,-10>,<10,28.5,10>,0.5 }    
        cylinder { <10,28.5,-10>,<-10,28.5,10>,0.5 }
        object  { link1 translate <-10,0,-10> }
        object  { link1 translate <10,0,-10> }
        object  { link1 translate <-10,0,10> }
        object  { link1 translate <10,0,10> }
        
        #if (detail=1)
                #declare i=0;
                #while (i<n)
                        object { nut1 scale (1+2*rand(s)) translate <(8+2*rand(s)),(1+25*rand(s)),(9-18*rand(s))> rotate 0*y }
                        #declare i=i+1;
                #end 
                #declare i=0;
                #while (i<n)
                        object { nut1 scale (1+2*rand(s)) translate <(8+2*rand(s)),(1+25*rand(s)),(9-18*rand(s))> rotate 90*y } 
                        #declare i=i+1;
                #end 
                #declare i=0;
                #while (i<n)
                        object { nut1 scale (1+2*rand(s)) translate <(8+2*rand(s)),(1+25*rand(s)),(9-18*rand(s))> rotate 180*y } 
                        #declare i=i+1;
                #end 
                #declare i=0;
                #while (i<n)
                        object { nut1 scale (1+2*rand(s)) translate <(8+2*rand(s)),(1+25*rand(s)),(9-18*rand(s))> rotate 270*y } 
                        #declare i=i+1;
                #end  
        #end                                   
}  
#end


#declare balcony = union { 
        union { 
                cylinder { 0*y,5*y,50 translate 40*y material { met_tex1 } }
                torus { 50,2.5 translate 40*y material { roof_tex } }
                torus { 66,2 translate 95*y material { roof_tex } } 
        }               
        #declare i=0; 
        #while (i<=31)      
                sphere_sweep {          
                        b_spline
                        11,
                        <0, 0, 0>, 3
                        <-5, 0, 0>, 3  
                        <-25, 15, 0>, 2   
                        <0, 30, 0>, 2             
                        <50, 40, 0>, 2 
                        <65, 70, 0>, 2                
                        <30, 100, 0>, 1
                        < 40, 115, 0>, 1      
                        < 50, 115, 0>, 1
                        < 55, 100, 0>, 1  
                        < 40, 100, 0>, 1 
                        tolerance 0.001
                        translate <25,5,0>
                        rotate (360/32*i)*y 
                        material { roof_tex }                  
                }       
                #declare i=i+1;
        #end        
}         

// bed
#declare bed = union {
        union { #declare side = union {
                        box { <0,0.5,-0.1>,<2.5,1,0.1> } 
                        cylinder { <0,1,0>,<2.5,1,0>,0.1 }
                }
                
                sphere_sweep {          
                        b_spline
                        15,   
                        <-20, -20, 0>, 4
                        <0, 0, 0>, 2
                        <-20, 15, 0>, 2  
                        <-35, 0, 0>, 2   
                        <-20, -20, 0>, 2             
                        <20, 0, 0>, 2 
                        <5, 30, 0>, 2                
                        <50, 60, 0>, 5 //center
                        <95, 30, 0>, 2
                        <80, 0, 0>, 2
                        <120, -20, 0>, 2        
                        <135, 0, 0>, 2
                        <120, 15, 0>, 2
                        <100, 0, 0>, 2
                        <120, -20, 0>, 4 
                        tolerance 0.001
                        translate <-50,0,0>
                        scale <0.0135,0.02,0.015>       
                        translate <1.25,1.7,4.5>
                                
                }
                
                torus { 0.5,0.05 rotate 90*x translate <1.25,1.5,4.5> } 
                torus { 0.3,0.03 rotate 90*x translate <1.25,2.3,4.5> }         
                
                object { side }
                cylinder { 0.13*y,1.3*y,0.13 }
                sphere { 0.13*y,0.13 } 
                object { tower1 scale 0.020 translate 1.3*y }     
                cylinder { 0.13*y,1.3*y,0.13 translate 2.5*x }
                sphere { 0.13*y,0.13 translate 2.5*x }  
                object { tower1 scale 0.020 translate <2.5,1.3,0> }   
                
                object { side translate 4.5*z }    
                cylinder { 0.13*y,2*y,0.13 translate 4.5*z } 
                sphere { 0.13*y,0.13 translate 4.5*z }
                object { tower1 scale 0.020 translate <0,2,4.5> }     
                cylinder { 0.13*y,2*y,0.13 translate <2.5,0,4.5> }
                sphere { 0.13*y,0.13 translate <2.5,0,4.5> } 
                object { tower1 scale 0.020 translate <2.5,2,4.5> }  
                
                object { side rotate y*-90 scale <1,1,1.8> }  
                object { side rotate y*-90 scale <1,1,1.8> translate 2.5*x }
                
                material { met_tex1 } 
        }  
        
        // mattress
        superellipsoid { <0.2,0.2> scale <1.2,0.25,2.2> translate <1.25,1.0,2.25> 
                texture {
                        pigment { color rgb 0.7 }  
                        normal { average 
                                normal_map {
                                        [1 quilted scale 0.2 rotate y*45] 
                                        [1 granite 0.1 scale 0.005] 
                                }        
                        }                
                }    
        }
} 


// glass of warm milk
#declare fi=0.95;

#declare glass = merge {
        difference {
                cylinder { -y*2,y*2,1 }
                sphere { -y*0.8,fi }
                cylinder { -y*0.8,y*2.01,fi }
                sphere { -y*1.9,0.1 }
        }
        torus { 0.975, 0.026 translate <0,2,0> }
        texture {
                pigment { Clear }
                finish {
                        reflection { 0.1,0.3 } 
                        conserve_energy 
                        ambient 0 diffuse 0  
                        specular 0.6 roughness 1/1000
                }                                        
        }     
        interior{ ior 1.5 }
} 


#declare milk = merge {
        sphere { -y*0.8,fi+0.00000001 }
        cylinder { -y*0.8,y*0.6,fi+0.00000001 }
        pigment { rgb < 1, 1, 1> }
        finish { reflection 0.3 }
}


#declare mglass = union {
        object { glass }
        object { milk }
        photons {
                target
                refraction on
                reflection on
                collect off
         } 
}                       


// drawer
#declare table = union { 
        union { 
                #declare frame = union { 
                        cylinder { -1*x,1*x,0.05 scale <1,1.2,1> translate -0.5*z }
                        cylinder { -1*x,1*x,0.05 scale <1,1.2,1> translate 0.5*z }
                        cylinder { -0.5*z,0.5*z,0.05 scale <1,1.2,1> translate -1*x }    
                        cylinder { -0.5*z,0.5*z,0.05 scale <1,1.2,1> translate 1*x }
                        sphere { 0,0.05 scale <1,1.2,1> translate <-1,0,-0.5> }     
                        sphere { 0,0.05 scale <1,1.2,1> translate <1,0,-0.5> }
                        sphere { 0,0.05 scale <1,1.2,1> translate <-1,0,0.5> }
                        sphere { 0,0.05 scale <1,1.2,1> translate <1,0,0.5> }
                }        
                         
                object { frame translate <0,2.05,0> }   
                object { frame translate <0,0.45,0> }
                box { <-1,0.45,-0.5>,<1,2.05,0.5> }
                cylinder { 0.45*y,2.05*y,0.025 translate <-1,0,-0.5> }
                cylinder { 0.45*y,2.05*y,0.025 translate <-1,0,0.5> } 
                cylinder { 0.45*y,2.05*y,0.025 translate <1,0,-0.5> } 
                cylinder { 0.45*y,2.05*y,0.025 translate <1,0,0.5> }
                
                superellipsoid { <0.1,0.1> scale <0.85,0.3,0.5> translate <0,1.6,-0.11>}
                sphere { 0,0.05 scale <1,1,2> translate <0,1.6,-0.65> }  
                torus { 0.11,0.015 rotate 90*x translate <0,1.5,-0.7> }  
                
                superellipsoid { <0.1,0.1> scale <0.85,0.3,0.5> translate <0,0.9,-0.11>}    
                sphere { 0,0.05 scale <1,1,2> translate <0,0.9,-0.65> }                  
                torus { 0.11,0.015 rotate 90*x translate <0,0.8,-0.7> }
                
                cylinder { 0.0*y,0.5*y,0.1 translate <-0.8,0,-0.3> }    
                cylinder { 0.0*y,0.5*y,0.1 translate <0.8,0,-0.3> }    
                cylinder { 0.0*y,0.5*y,0.1 translate <-0.8,0,0.3> }    
                cylinder { 0.0*y,0.5*y,0.1 translate <0.8,0,0.3> }     
                
                material { met_tex1 }
        } 
        
        // place a glass        
        object { mglass scale 0.15 translate <-0.5,2.35,-0.2> }
} 


// ladder to heaven
#declare ladder = union {
        box { <-0.1,0.2,-0.1>,<0.2,13,0.0> translate -0.6*z }  
        box { <-0.1,0.2,-0.1>,<0.2,13,0.0> translate 0.6*z }
        cylinder { <0.2,0.2,-0.05>,<0.2,13,-0.05>,0.05 translate -0.6*z }    
        cylinder { <0.2,0.2,-0.05>,<0.2,13,-0.05>,0.05 translate 0.6*z }  
        cylinder { <-0.1,0.2,-0.05>,<-0.1,13,-0.05>,0.05 translate -0.6*z }    
        cylinder { <-0.1,0.2,-0.05>,<-0.1,13,-0.05>,0.05 translate 0.6*z } 
        cylinder { <0.05,0.2,-0.7>,<0.05,13,-0.7>,0.05 }         
        cylinder { <0.05,0.2,0.6>,<0.05,13,0.6>,0.05 }
                            
        #declare i=2;
        #while (i<=11)
                cylinder { <0.05,0,-0.6>,<0.05,0,0.55>,0.12 translate 1*i*y }                  
                #declare i=i+1;
        #end
        
        material { met_tex1 } 
}    


//bridge pillars
#declare pillars = union {
        object { col2 scale 0.9 translate <10,0,0> } 
        object { col2 scale 0.9 translate <-10,0,0> } 
        cylinder { <-10,28.5,0>,<10,28.5,0>,0.5 }    
        cylinder { <-10,28.5,0>,<10,0,0>,0.3 }  
        cylinder { <-10,0,0>,<10,28.5,0>,0.3 }      
        object  { link1 translate <-10,0,0> } 
        object  { link1 translate <10,0,0> }
}
                        
                        
// bridge with all objects
#declare bridge =
        union {
                #declare i=0;
                #while (i<=359)
                        union {
                                superellipsoid { <0.2,0.2> scale <4,0.4,0.6> translate y*-0.2 }
                                object { fence1 translate <-3.6,0,0.5> }  
                                object { fence1 translate <3.6,0,0.5> } 
                                translate 70*y
                                rotate x*1*i
                                material { met_tex1 }
                        }             
                        #declare i=i+1;
                #end
                
                object { bed scale 1.35 rotate 10*y translate <-2.5,70.2,0> rotate 4*x }   
                
                // supporting pillars
                #declare i=0;
                #while (i<=11)
                        union {
                                object { pillars }
                                object { pillars translate -30*y }    
                                object { pillars translate -60*y } 
                                object { pillars translate -90*y } 
                                scale 0.3 translate y*60 rotate 360/12*i*x
                                material { met_tex1 } 
                        }                    
                        #declare i=i+1;
                #end          
                         
                object { ladder rotate 40*z translate <-3.5,70.2,0> rotate 14*x }      
                object { table scale 1.2 rotate y*13 translate <1.6,70.2,0> rotate 10.5*x  }                         
        }           
                      
        
// buildnigs assembly 

#declare building0 = union {
                object { floorr scale 0.2 translate <0,0,0> }    
                object { cube1(10) scale 0.2 translate <0,0,0> }    
                object { cube1(10) scale 0.2 translate <0,6,0> }  
                object { cube1(10) scale 0.2 translate <0,12,0> }
                object { floorr scale 0.2 translate <0,18.1,0> } 
                object { balcony scale 1/40 translate <2,7,2> }       
                object { balcony scale 1/40 translate <2,13,2> }        
                object { tower1 scale 0.05 translate <-2,18.1,-2> } 
                object { tower1 scale 0.05 translate <-2,18.1,2> }
                object { tower1 scale 0.05 translate <2,18.1,-2> }
                object { tower1 scale 0.05 translate <2,18.1,2> }  
                material { met_tex1 }
}     
        

#declare building1 = union {
          
        #declare part1 = union {                                                               
                object { cube1(30) scale 0.2 translate <-0,0,0> } 
                object { cube1(30) scale 0.2 translate <-0,6,0> }           
                object { cube1(30) scale 0.2 translate <-0,12,0> }    
                object { cube1(20) scale 0.2 translate <-0,18,0> }
                object { cube1(30) scale 0.2 translate <-0,24,0> } 
                object { cube1(20) scale 0.2 translate <-0,30,0> } 
                object { cube1(30) scale 0.2 translate <-0,36,0> } 
                object { cube1(20) scale 0.2 translate <-0,42,0> }            
                object { floorr scale 0.2 translate <-0,48.1,0> }
        }            
        
        object { tower3 scale 0.25 translate <0,48,0> }  
        object { part1 translate <-2.5,0,-2.5> } 
        object { part1 translate <2.5,0,-2.5> } 
        object { part1 translate <-2.5,0,2.5> } 
        object { part1 translate <2.5,0,2.5> }
               
        
        object { part1 translate <2.5,-25,-7> }        
        object { tower3 scale 0.12 translate <2.5,23,-7> }  
        
        material { met_tex1 }
}              
 
 
#declare building2 = union {  
        object { part1 translate <0,0,0> }   
        object { tower5 scale 0.12 translate 48*y } 
        object { tower3 scale 0.12 translate 51.6*y } 
        object { tower1 scale 0.05 translate <-2,48.1,-2> } 
        object { tower1 scale 0.05 translate <-2,48.1,2> }
        object { tower1 scale 0.05 translate <2,48.1,-2> }
        object { tower1 scale 0.05 translate <2,48.1,2> }  
        
        material { met_tex1 }       
}            


#declare building3 = union {  
        object { part1 translate <0,0,0> }   
        object { tower4(28) scale 0.13 rotate 0*y translate <2,46,0> }    
        object { tower4(50) scale 0.13 rotate 90*y translate <0,46,-2> } 
        object { tower4(20) scale 0.13 rotate 180*y translate <-2,46,0> } 
        object { tower4(30) scale 0.13 rotate 270*y translate <0,46,2> } 
        object { tower1 scale 0.05 translate <-2,48.1,-2> } 
        object { tower1 scale 0.05 translate <-2,48.1,2> }
        object { tower1 scale 0.05 translate <2,48.1,-2> }
        object { tower1 scale 0.05 translate <2,48.1,2> } 
        
        material { met_tex1 }        
}    


#declare building4 = union { 
        #declare part2 = union { 
                object { floorr scale 0.2 translate <-0,-0.1,0> }                               
                object { cube1(30) scale 0.2 translate <-0,-0,0> }     
                object { floorr scale 0.2 translate <-0,6.1,0> }
        } 
         
        object { tower3 scale 0.25 translate <0,6,0> }  
        object { part2 translate <-2.5,0,-2.5> } 
        object { part2 translate <2.5,0,-2.5> } 
        object { part2 translate <-2.5,0,2.5> } 
        object { part2 translate <2.5,0,2.5> }
        object { balcony scale 1/40 translate <-4.5,1,-4.5> }  
        object { balcony scale 1/40 translate <-4.5,1,4.5> }  
        object { balcony scale 1/40 translate <4.5,1,-4.5> }  
        object { balcony scale 1/40 translate <4.5,1,4.5> }  
        
        material { met_tex1 }                  
} 


#declare building5 = union {  
        object { part1 }        
        object { tower3 scale 0.10 translate <0,48,0> }  
        object { tower4(28) scale 0.13 rotate 90*y translate <0,47,-2> }    
        object { tower4(38) scale 0.13 rotate 180*y translate <-2,46,0> }  
        object { tower4(50) scale 0.13 rotate 270*y translate <0,40,2> }  
        object { tower4(38) scale 0.13 rotate 0*y translate <2,47,0> } 
        object { tower1 scale 0.05 translate <-2,48.1,-2> } 
        object { tower1 scale 0.05 translate <-2,48.1,2> }
        object { tower1 scale 0.05 translate <2,48.1,-2> }
        object { tower1 scale 0.05 translate <2,48.1,2> }  
        
        material { met_tex1 }      
} 


#declare building6 = union {
                object { part1 }       
                object { balcony scale 1/40 translate <2,43,2> }        
                object { tower1 scale 0.05 translate <-2,48.1,-2> } 
                object { tower1 scale 0.05 translate <-2,48.1,2> }
                object { tower1 scale 0.05 translate <2,48.1,-2> }
                object { tower1 scale 0.05 translate <2,48.1,2> } 
                
                material { met_tex1 }
}                             

 
//***** MAIN WORLD STRUCTURE      

#declare a=seed(367);  
#declare b=seed(36994);
#declare c=seed(11674);
#declare d=seed(4);
#declare e=seed(777);
#declare f=seed(36);   
#declare g=seed(76679984);      


// buildings and toruses placed at random

#declare i=0; 
#while (i<=157)
        object { building2 scale (0.6-rand(e)*0.3) translate <0,(42-10*rand(d)),0> rotate <(360*rand(g)),(360*rand(f)),(360*rand(g))> }
        #declare i=i+1;
#end  


#declare i=0;
#while (i<=180)
        object { building0 translate <0,(50-10*rand(c)),0> rotate <(360*rand(g)),(360*rand(a)),(360*rand(f))> }
        #declare i=i+1;
#end    
     
  
#declare i=0;  
#while (i<=50)
        union {
                torus { 50,(0.03+0.2*rand(a)) }  
                #declare j=0;
                #while (j<150)
                        torus { 0.2,0.12 scale <1,5,1> rotate 90*x translate 50*x rotate 2.4*y*j }
                        #declare j=j+1;         
                #end
                scale (1-rand(a)*0.3) 
                rotate <(360*rand(a)),(360*rand(a)),(360*rand(a))>
                material { met_tex1 } 
                #declare i=i+1; 
        }             
#end  
   

// cityscape 
 
object { building6 rotate -90*y translate 35*y rotate <55,0,35> }                                         
object { building1 rotate 20*y translate 50*y rotate <45,0,40> }  
object { building5 rotate 200*y translate 50*y rotate <52,0,38> }   
object { building6 rotate 60*y translate 33*y rotate <28,0,39> }    
object { building5 rotate 0*y translate 25*y rotate <20,0,35> }  
   
object { building3 rotate -5*y translate 30*y rotate <10,0,45> }    
object { building4 scale 0.7 rotate -5*y translate 60*y rotate <0,0,-12> }       
object { building3 scale 0.7 rotate -15*y translate 25*y rotate <20,0,-17> }
                  
object { building2 rotate -75*y translate 8*y rotate <-20,0,10> }    
                                                                             
                          
// bridge

object { bridge rotate <0,0,-5> }     


//*****MOON

// moon texture

#declare t_moon=
texture{
 pigment{
  onion
  color_map{ 
   [0.0 rgb 0.0]
   [1.0 rgb 0.7]
  }
 }
}


// moon halo with media

#local DensityHalo=density {
        spherical       
        turbulence 0.01
        color_map {
            [0.0 Black]
            [1.0 White]
        }
}
    
#local mediaHalo = media {     
        emission 0.2
        intervals 5 samples 1, 5
        confidence 0.9999
        variance 1/10
        density { DensityHalo }
}                    
    
#declare halo = sphere {
        0,1 
        texture{ pigment { Clear } finish { ambient 0 diffuse 0 } }
        interior{ media { mediaHalo } }
        hollow no_shadow
        scale 1.2
}

// moon isosurface

#declare Moon= union {
        isosurface {
                function { (x*x+y*y+z*z-1)+f_granite(x*2,y*2,z*2)*f_agate(x,y,z)*.05 }
                max_gradient 3.8
                contained_by { sphere { 0,1 } }
                texture{ t_moon }
        }
        halo  
}            

object { Moon scale 6 translate <-10,75,19> }         
    
                                                                            

//*****STARS

// some nice media stars  

#local mediaStar = media {     
        emission 1
        intervals 5 samples 1, 5
        confidence 0.9999
        variance 1/10
        density { DensityHalo }
}                    
    
#declare star = sphere {
        0,1 
        texture { pigment { Clear } finish { ambient 0 diffuse 0 } }
        interior { media { mediaStar } }
        hollow no_shadow
        scale 1.2
}


#declare h=seed(8557);  
#declare j=seed(86994);
#declare k=seed(88);

#declare stars = union {
        #declare i=0;
        #while (i<2000)
                object { star
                        scale rand(h) translate 350*z rotate <-60*rand(j)+20,rand(k)*360,0>
                }                                                                            
                #declare i=i+1;
        #end        
}

stars     


//*****THATS IT         
